
=======
Cartopy
=======

.. image:: http://scitools.org.uk/cartopy/docs/latest/_static/cartopy.png

Cartopy is a Python package designed to make drawing maps for data analysis and visualisation easy.

It features:

* object oriented projection definitions
* point, line, polygon and image transformations between projections
* integration to expose advanced mapping in matplotlib with a simple and intuitive interface
* powerful vector data handling by integrating shapefile reading with Shapely capabilities 

Documentation can be found at http://scitools.org.uk/cartopy/docs/latest/.

----
Code
----
Cartopy is licenced under GNU Lesser General Public License (LGPLv3).
Development occurs at https://github.com/SciTools/cartopy.

